api.events.v1.nids — Argus-Toolbelt 1.0 documentation

# Source code for api.events.v1.nids

    """Autogenerated API"""
    import requests
    from argus_cli.plugin import register_command

    @register_command(extending=('events','v1','nids'))
    def list_n_i_d_s_events(customerID: list = None, signature: list = None, ip: list = None, startTimestamp: int = None, endTimestamp: int = None, limit: int = 25, offset: int = 0,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Simple search for NIDS events (PUBLIC)

        :param list customerID: Limit to customerID
        :param list signature: Limit to signature
        :param list ip: Limit to ip/network
        :param int startTimestamp: Limit to events after this timestamp (default is last 24 hours)
        :param int endTimestamp: Limit to events before this timestamp
        :param int limit: Limit results
        :param int offset: Offset results
        :raises AuthenticationFailedException: on 401
        :raises ValidationFailedException: on 412
        :raises AccessDeniedException: on 403
        :returns: {"offset": 612, "limit": 538, "responseCode": 200, "count": 35, "data": [{"properties": {"additionalProperties": "Artist between security page."}, "comments": [{"timestamp": 862912156, "comment": "Attack focus face."}], "count": 951, "engineTimestamp": 588072062, "protocolID": 204, "uri": "Tough grow quite administration main clearly.", "timestamp": 1260636743, "severity": "critical", "flags": ["SEVERITY_ADJUSTED"], "id": "Customer step create remember behavior all whole."}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Eye official item professional try mother mean.", "messageTemplate": "Relate least brother beautiful special.", "field": "Involve center tend enter quickly war.", "parameter": {}, "timestamp": 497441210}], "currentPage": 94, "size": 205}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/events/v1/nids".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if limit:
            body.update({"limit": limit})

        if offset:
            body.update({"offset": offset})

        if customerID:
            body.update({"customerID": customerID})

        if signature:
            body.update({"signature": signature})

        if ip:
            body.update({"ip": ip})

        if startTimestamp:
            body.update({"startTimestamp": startTimestamp})

        if endTimestamp:
            body.update({"endTimestamp": endTimestamp})

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('events','v1','nids'))
    def find_n_i_d_s_events(limit: int = None, offset: int = None, customerID: list = None, eventIdentifier: list = None, locationID: list = None, alarmID: list = None, attackCategoryID: list = None, sourceGeoCountry: list = None, destinationGeoCountry: list = None, geoCountry: list = None, properties: dict = None, sensorID: list = None, subCriteria: list = None, signature: list = None, sortBy: list = None, startTimestamp: int = None, endTimestamp: int = None, includeFlags: list = None, excludeFlags: list = None, lastUpdatedTimestamp: int = None, destinationIP: list = None, sourceIP: list = None, ip: list = None, destinationPort: list = None, sourcePort: list = None, port: list = None, minSeverity: str = None, maxSeverity: str = None, includeDeleted: bool = 'False', exclude: bool = 'False',json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Search for NIDS events (PUBLIC)

        :param int limit: Limit results
        :param int offset: Offset results
        :param list customerID: Limit result to objects belonging to these customers
        :param list eventIdentifier: Search for events specified by full ID (type/timestamp/customerid/eventid)
        :param list locationID: Search for events having these locations
        :param list alarmID: Search for events having an attack identifier (signature) mapped to any of these alarms
        :param list attackCategoryID: Search for events having an attack identifier (signature) mapped to any of these categories
        :param list sourceGeoCountry: Search for events where source IP is registered in any of these countries
        :param list destinationGeoCountry: Search for events where destination IP is registered in any of these countries
        :param list geoCountry: Search for events where source or destination IP is registered in any of these countries
        :param dict properties: Search for events having these properties (logical AND)
        :param list sensorID:
        :param list subCriteria:
        :param list signature:
        :param list sortBy: Order results by these properties (prefix with - to sort descending)
        :param int startTimestamp: Search objects from this timestamp
        :param int endTimestamp: Search objects until this timestamp
        :param list includeFlags: Search objects with these flags set
        :param list excludeFlags: Exclude objects with these flags set
        :param int lastUpdatedTimestamp: Search for events updated after this timestamp
        :param list destinationIP:
        :param list sourceIP:
        :param list ip:
        :param list destinationPort:
        :param list sourcePort:
        :param list port:
        :param str minSeverity:
        :param str maxSeverity:
        :param bool includeDeleted: Also include deleted objects (where implemented)
        :param bool exclude: Exclude these criteria from the parent criteria
        :raises AuthenticationFailedException: on 401
        :raises ValidationFailedException: on 412
        :raises AccessDeniedException: on 403
        :returns: {"offset": 808, "limit": 512, "responseCode": 200, "count": 204, "data": [{"properties": {"additionalProperties": "Admit hard hotel test with."}, "comments": [{"timestamp": 172626318, "comment": "Campaign at street skin house."}], "count": 142, "engineTimestamp": 103665467, "protocolID": 997, "uri": "Must again value personal difference wife.", "timestamp": 666148246, "severity": "low", "flags": ["SNAPSHOT"], "id": "Believe magazine buy detail treat contain camera."}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Ok possible player organization beautiful use certainly training.", "messageTemplate": "Particularly relate what.", "field": "Minute film room together central across seat.", "parameter": {}, "timestamp": 1322993011}], "currentPage": 121, "size": 554}
        """
        from requests import post
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/events/v1/nids/search".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if limit:
            body.update({"limit": limit})

        if offset:
            body.update({"offset": offset})

        if includeDeleted:
            body.update({"includeDeleted": includeDeleted})

        if customerID:
            body.update({"customerID": customerID})

        if exclude:
            body.update({"exclude": exclude})

        if eventIdentifier:
            body.update({"eventIdentifier": eventIdentifier})

        if locationID:
            body.update({"locationID": locationID})

        if alarmID:
            body.update({"alarmID": alarmID})

        if attackCategoryID:
            body.update({"attackCategoryID": attackCategoryID})

        if sourceGeoCountry:
            body.update({"sourceGeoCountry": sourceGeoCountry})

        if destinationGeoCountry:
            body.update({"destinationGeoCountry": destinationGeoCountry})

        if geoCountry:
            body.update({"geoCountry": geoCountry})

        if properties:
            body.update({"properties": properties})

        if sensorID:
            body.update({"sensorID": sensorID})

        if subCriteria:
            body.update({"subCriteria": subCriteria})

        if signature:
            body.update({"signature": signature})

        if sortBy:
            body.update({"sortBy": sortBy})

        if startTimestamp:
            body.update({"startTimestamp": startTimestamp})

        if endTimestamp:
            body.update({"endTimestamp": endTimestamp})

        if includeFlags:
            body.update({"includeFlags": includeFlags})

        if excludeFlags:
            body.update({"excludeFlags": excludeFlags})

        if lastUpdatedTimestamp:
            body.update({"lastUpdatedTimestamp": lastUpdatedTimestamp})

        if destinationIP:
            body.update({"destinationIP": destinationIP})

        if sourceIP:
            body.update({"sourceIP": sourceIP})

        if ip:
            body.update({"ip": ip})

        if destinationPort:
            body.update({"destinationPort": destinationPort})

        if sourcePort:
            body.update({"sourcePort": sourcePort})

        if port:
            body.update({"port": port})

        if minSeverity:
            body.update({"minSeverity": minSeverity})

        if maxSeverity:
            body.update({"maxSeverity": maxSeverity})

        response = post(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response